@@ -25,6 +25,13 @@ callNonmemDirect <- function(file.mod,path.nonmem){
 ##'     where the input data file is stored. This would be ".." if the
 ##'     run directory is created in a directory where the data is
 ##'     stored.
+##' @param clean The degree of cleaning (file removal) to do after
+##'     Nonmem execution. If `method.execute=="psn"`, this is passed
+##'     to PSN's `execute`. If `method.execute=="nmsim"` a similar
+##'     behavior is applied, even though not as granular. NMsim's
+##'     internal method only distinguishes between 0 (no cleaning),
+##'     any integer 1-4 (default, quite a bit of cleaning) and 5
+##'     (remove temporary dir completely).
 ##' @import NMdata
 ##' @importFrom R.utils getAbsolutePath
 ##' @return A bash shell script for execution of Nonmem
@@ -32,7 +39,7 @@ callNonmemDirect <- function(file.mod,path.nonmem){
 
 ## do not export. NMexec will call this.
 
-NMexecDirectory <- function(file.mod,path.nonmem,files.needed,dir.data="..",system.type){
+NMexecDirectory <- function(file.mod,path.nonmem,files.needed,dir.data="..",system.type,clean){
     
     ## if(missing(method)||is.null(method)) method <- "directory"
     ## if(!(is.characther(method) && length(method)==1)||!method%in%cc(directory,direct)){
@@ -98,7 +105,7 @@ NMexecDirectory <- function(file.mod,path.nonmem,files.needed,dir.data="..",syst
             sec.data.new <- paste("$DATA",sec.data.new)
         }
     }
-    NMwriteSection(files=file.mod,section="DATA",newlines=sec.data.new,newfile=file.mod.tmp,quiet=TRUE)
+    NMwriteSection(files=file.mod,section="DATA",newlines=sec.data.new,newfile=file.mod.tmp,quiet=TRUE,backup = FALSE)
 
 ### copy .phi if found
     ## file.copy(fnExtension(file.mod,"phi"),dir.tmp)
@@ -115,28 +122,15 @@ NMexecDirectory <- function(file.mod,path.nonmem,files.needed,dir.data="..",syst
 
     dir.mod.abs <- getAbsolutePath(dir.mod)
     if(system.type=="linux"){
-        lines.bash <- c(
-            "#!/bin/bash"
-           ,sprintf("%s %s %s",path.nonmem,fn.mod,fnExtension(fn.mod,".lst"))
-           ,sprintf("cp \'%s\' \'%s\'",paste(meta.tables[,name],collapse=" "),dir.mod.abs)
-### this works when file.mod is a relative path
-            ## ,paste("find",".","-type f -name",paste0("*.",exts.cp)," -exec cp {} ",file.path(getwd(),dir.mod)," \\;")
-            ## ,sprintf("cp %s %s",paste(meta.tables[,name],collapse=" "),file.path(getwd(),dir.mod))
 
-### copy wanted files back to orig location of file.mod 
-           ,paste0("find . -type f -name ",paste0("\'*.",exts.cp,"\'")," -exec cp {} \'",dir.mod.abs,"\' \\;")
-
-           ,""
-        )
-        
+        lines.script <- NMrunLin(fn.mod,dir.mod.abs,exts.cp,meta.tables,path.nonmem=path.nonmem,clean=clean)
         path.script <- file.path(dir.tmp,"run_nonmem.sh")
-
-        writeTextFile(lines.bash,path.script)
-        Sys.chmod(path.script,mode="0577")
+        writeTextFile(lines.script,path.script)
+        Sys.chmod(path.script, mode = "0777", use_umask = FALSE)
     }
     
     if(system.type=="windows"){
-        lines.script <- NMrunWin(fn.mod,dir.mod.abs,exts.cp,meta.tables,path.nonmem=path.nonmem)
+        lines.script <- NMrunWin(fn.mod,dir.mod.abs,exts.cp,meta.tables,path.nonmem=path.nonmem,clean=clean)
         path.script <- file.path(dir.tmp,"run_nonmem.bat")
         writeTextFile(lines.script,path.script)
     }
